pub struct AvatarUploadCredential { /* private fields */ }Implementations
Sourceimpl AvatarUploadCredential
impl AvatarUploadCredential
pub fn present( &self, server_params: &GenericServerPublicParams, randomness: RandomnessBytes, ) -> AvatarUploadCredentialPresentation
Sourcepub fn cm(&self) -> CommitmentPoint
pub fn cm(&self) -> CommitmentPoint
The Pedersen commitment cm, used as a stable unlinkable identifier.
Sourcepub fn cm_bytes(&self) -> [u8; 32]
pub fn cm_bytes(&self) -> [u8; 32]
The compressed-Ristretto encoding of Pedersen commitment cm, suitable for bridge consumers.
Sourcepub fn redemption_time(&self) -> Timestamp
pub fn redemption_time(&self) -> Timestamp
The redemption time the issuing server chose for this credential.