pub struct AvatarUploadCredentialPresentation { /* private fields */ }Implementations
Sourceimpl AvatarUploadCredentialPresentation
impl AvatarUploadCredentialPresentation
pub fn verify( &self, current_time: Timestamp, server_params: &GenericServerSecretParams, ) -> Result<(), ZkGroupVerificationFailure>
Sourcepub fn cm(&self) -> CommitmentPoint
pub fn cm(&self) -> CommitmentPoint
The Pedersen commitment cm, used as a stable unlinkable identifier.
Sourcepub fn cm_bytes(&self) -> [u8; 32]
pub fn cm_bytes(&self) -> [u8; 32]
The compressed-Ristretto encoding of Pedersen commitment cm, suitable for bridge consumers.
pub fn redemption_time(&self) -> Timestamp